@@ -30,6 +30,15 @@ signer = leselys.core.signer
 # Set password
 @app.route('/api/set_password', methods=['POST'])
 def set_password():
+    # For demo
+    heroku_urls = [
+            "http://leselys.herokuapp.com/api/set_password", 
+            "https://leselys.herokuapp.com/api/set_password",
+            "http://leselys.herokuapp.com:80/api/set_password",
+            "https://leselys.herokuapp.com:443/api/set_password"]
+    if request.url in heroku_urls:
+        return jsonify(success=False, content="Funny little boy. Ip stored.")
+
     if storage.get_password():
         if not session.get('logged_in'):
             if request.args.get('jsonify', "true") == "false":
@@ -38,13 +47,16 @@ def set_password():
                 return jsonify(success=False, content="Not allowed")
 
     password = request.form.get('password')
+    if not password:
+        return jsonify(success=False, content="Can't be empty")
+
     storage.set_password(password)
 
     session['logged_in'] = True
     if request.args.get('jsonify', "true") == "false":
         rsp = redirect(url_for('home'))
     else:
-        rsp = make_response(jsonify(success=True, output="Password setted."))
+        rsp = make_response(jsonify(success=True, content="Password setted."))
     return rsp
 
 
@@ -56,6 +68,8 @@ def get_counters():
     res = []
     for feed in feeds:
         res.append((feed['id'], feed['counter']))
+
+    res.append(('combined-feed', reader.get_combined_feed().get('counter', 0)))
     return jsonify(success=True, content=res)
 
 
@@ -74,15 +88,20 @@ def remove(feed_id):
 
 
 # Return list of entries for given feed_id
-# Or all if feed_id not specified
-@app.route('/api/get', defaults={'feed_id': False})
 @app.route('/api/get/<feed_id>')
 @login_required
 def get(feed_id):
+    start = int(request.args.get('start', 0))
+    stop = int(request.args.get('stop', 50))
+
+    if feed_id in ['combined-feed', 'stared-feed']:
+        feed_type = feed_id
+        feed_id = False
+    else:
+        feed_type = None
+
     order_type = request.args.get('order_type', 'user')
-    start = request.args.get('start', 0)
-    end = request.args.get('end', 100)
-    return jsonify(success=True, content=reader.get(feed_id, order_type, start, end))
+    return jsonify(success=True, content=reader.get(feed_id, feed_type, order_type, start, stop))
 
 
 # Set story as readed
@@ -126,8 +145,12 @@ def all_unread(feed_id):
 @login_required
 @cached(10)
 def import_opml():
-    opml_file = request.form['file']
-    for feed in retrieve_feeds_from_opml(opml_file):
+    opml_file = request.files['file']
+    try:
+        feeds = retrieve_feeds_from_opml(opml_file.read())
+    except Exception as err:
+        return jsonify(success=False, output="Bad OPML file (%s)" % err)
+    for feed in feeds:
         t = Thread(target=reader.add, args=(feed['url'],))
         t.start()
     return jsonify(success=True, output='Imported file is processing...')
