@@ -3,4 +3,4 @@
 themes = {'Bootstrap': 'bootstrap.min.css',
           'Readable': 'readable.min.css',
           'Journal': 'journal.min.css',
-          'Flat UI': 'flat-ui.css'}
+          'Flat UI': 'flat-ui.min.css'}
